@@ -310,6 +310,87 @@ class TestUtils(test_utils.TestCase):
     def test_is_ascii_string(self):
         self.assertFalse(utils.is_ascii(u'\u2665'))
 
+    def test_format_size(self):
+        self.assertEqual("999", utils.format_size(999))
+        self.assertEqual("100K", utils.format_size(100000))
+        self.assertEqual("2M", utils.format_size(2000000))
+        self.assertEqual(
+            "16.4M", utils.format_size(16361280)
+        )
+        self.assertEqual(
+            "1.6G", utils.format_size(1576395005)
+        )
+        self.assertEqual("0", utils.format_size(None))
+
+    def test_backward_compat_col_lister(self):
+        fake_col_headers = ['ID', 'Name', 'Size']
+        columns = ['Display Name']
+        column_map = {'Display Name': 'Name'}
+        results = utils.backward_compat_col_lister(fake_col_headers,
+                                                   columns,
+                                                   column_map)
+        self.assertIsInstance(results, list)
+        self.assertIn('Display Name', results)
+        self.assertNotIn('Name', results)
+        self.assertIn('ID', results)
+        self.assertIn('Size', results)
+
+    def test_backward_compat_col_lister_no_specify_column(self):
+        fake_col_headers = ['ID', 'Name', 'Size']
+        columns = []
+        column_map = {'Display Name': 'Name'}
+        results = utils.backward_compat_col_lister(fake_col_headers,
+                                                   columns,
+                                                   column_map)
+        self.assertIsInstance(results, list)
+        self.assertNotIn('Display Name', results)
+        self.assertIn('Name', results)
+        self.assertIn('ID', results)
+        self.assertIn('Size', results)
+
+    def test_backward_compat_col_lister_with_tuple_headers(self):
+        fake_col_headers = ('ID', 'Name', 'Size')
+        columns = ['Display Name']
+        column_map = {'Display Name': 'Name'}
+        results = utils.backward_compat_col_lister(fake_col_headers,
+                                                   columns,
+                                                   column_map)
+        self.assertIsInstance(results, list)
+        self.assertIn('Display Name', results)
+        self.assertNotIn('Name', results)
+        self.assertIn('ID', results)
+        self.assertIn('Size', results)
+
+    def test_backward_compat_col_showone(self):
+        fake_object = {'id': 'fake-id',
+                       'name': 'fake-name',
+                       'size': 'fake-size'}
+        columns = ['display_name']
+        column_map = {'display_name': 'name'}
+        results = utils.backward_compat_col_showone(fake_object,
+                                                    columns,
+                                                    column_map)
+        self.assertIsInstance(results, dict)
+        self.assertIn('display_name', results)
+        self.assertIn('id', results)
+        self.assertNotIn('name', results)
+        self.assertIn('size', results)
+
+    def test_backward_compat_col_showone_no_specify_column(self):
+        fake_object = {'id': 'fake-id',
+                       'name': 'fake-name',
+                       'size': 'fake-size'}
+        columns = []
+        column_map = {'display_name': 'name'}
+        results = utils.backward_compat_col_showone(fake_object,
+                                                    columns,
+                                                    column_map)
+        self.assertIsInstance(results, dict)
+        self.assertNotIn('display_name', results)
+        self.assertIn('id', results)
+        self.assertIn('name', results)
+        self.assertIn('size', results)
+
 
 class NoUniqueMatch(Exception):
     pass
@@ -486,11 +567,50 @@ class TestFindResource(test_utils.TestCase):
                          utils.format_dict({'a': 'b', 'c': 'd', 'e': 'f'}))
         self.assertEqual(expected,
                          utils.format_dict({'e': 'f', 'c': 'd', 'a': 'b'}))
+        self.assertIsNone(utils.format_dict(None))
+
+    def test_format_dict_of_list(self):
+        expected = "a=a1, a2; b=b1, b2; c=c1, c2; e="
+        self.assertEqual(expected,
+                         utils.format_dict_of_list({'a': ['a2', 'a1'],
+                                                    'b': ['b2', 'b1'],
+                                                    'c': ['c1', 'c2'],
+                                                    'd': None,
+                                                    'e': []})
+                         )
+        self.assertEqual(expected,
+                         utils.format_dict_of_list({'c': ['c1', 'c2'],
+                                                    'a': ['a2', 'a1'],
+                                                    'b': ['b2', 'b1'],
+                                                    'e': []})
+                         )
+        self.assertIsNone(utils.format_dict_of_list(None))
+
+    def test_format_dict_of_list_with_separator(self):
+        expected = "a=a1, a2\nb=b1, b2\nc=c1, c2\ne="
+        self.assertEqual(expected,
+                         utils.format_dict_of_list({'a': ['a2', 'a1'],
+                                                    'b': ['b2', 'b1'],
+                                                    'c': ['c1', 'c2'],
+                                                    'd': None,
+                                                    'e': []},
+                                                   separator='\n')
+                         )
+        self.assertEqual(expected,
+                         utils.format_dict_of_list({'c': ['c1', 'c2'],
+                                                    'a': ['a2', 'a1'],
+                                                    'b': ['b2', 'b1'],
+                                                    'e': []},
+                                                   separator='\n')
+                         )
+        self.assertIsNone(utils.format_dict_of_list(None,
+                                                    separator='\n'))
 
     def test_format_list(self):
         expected = 'a, b, c'
         self.assertEqual(expected, utils.format_list(['a', 'b', 'c']))
         self.assertEqual(expected, utils.format_list(['c', 'b', 'a']))
+        self.assertIsNone(utils.format_list(None))
 
     def test_format_list_of_dicts(self):
         expected = "a='b', c='d'\ne='f'"
@@ -500,6 +620,7 @@ class TestFindResource(test_utils.TestCase):
         self.assertEqual(expected, utils.format_list_of_dicts(unsorted_data))
         self.assertEqual('', utils.format_list_of_dicts([]))
         self.assertEqual('', utils.format_list_of_dicts([{}]))
+        self.assertIsNone(utils.format_list_of_dicts(None))
 
     def test_format_list_separator(self):
         expected = 'a\nb\nc'
